==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToInstanceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstance;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateEventToInstanceSetImpl extends InstanceSet<CreateEventToInstanceSet,CreateEventToInstance> implements CreateEventToInstanceSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( CreateEventToInstance createeventtoinstance : this ) createeventtoinstance.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToInstance createeventtoinstance : this ) createeventtoinstance.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToInstance createeventtoinstance : this ) createsmeventstatementset.add( createeventtoinstance.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }
    @Override
    public V_VARSet R711_has_recipient_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( CreateEventToInstance createeventtoinstance : this ) v_varset.add( createeventtoinstance.R711_has_recipient_V_VAR() );
        return v_varset;
    }


    @Override
    public CreateEventToInstance nullElement() {
        return CreateEventToInstanceImpl.EMPTY_CREATEEVENTTOINSTANCE;
    }

    @Override
    public CreateEventToInstanceSet emptySet() {
      return new CreateEventToInstanceSetImpl();
    }

    @Override
    public CreateEventToInstanceSet value() {
        return this;
    }

    @Override
    public List<CreateEventToInstance> elements() {
        return Arrays.asList(toArray(new CreateEventToInstance[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToInstanceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstance;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToInstanceSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateEventToInstanceSetImpl extends InstanceSet<CreateEventToInstanceSet,CreateEventToInstance> implements CreateEventToInstanceSet {

    public CreateEventToInstanceSetImpl() {
    }

    public CreateEventToInstanceSetImpl(Comparator<? super CreateEventToInstance> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToInstance createeventtoinstance : this ) createeventtoinstance.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( CreateEventToInstance createeventtoinstance : this ) createeventtoinstance.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToInstance createeventtoinstance : this ) createsmeventstatementset.add( createeventtoinstance.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }
    @Override
    public V_VARSet R711_has_recipient_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( CreateEventToInstance createeventtoinstance : this ) v_varset.add( createeventtoinstance.R711_has_recipient_V_VAR() );
        return v_varset;
    }


    @Override
    public CreateEventToInstance nullElement() {
        return CreateEventToInstanceImpl.EMPTY_CREATEEVENTTOINSTANCE;
    }

    @Override
    public CreateEventToInstanceSet emptySet() {
      return new CreateEventToInstanceSetImpl();
    }

    @Override
    public CreateEventToInstanceSet emptySet(Comparator<? super CreateEventToInstance> comp) {
      return new CreateEventToInstanceSetImpl(comp);
    }

    @Override
    public CreateEventToInstanceSet value() {
        return this;
    }

    @Override
    public List<CreateEventToInstance> elements() {
        return Arrays.asList(toArray(new CreateEventToInstance[0]));
    }

}
